SCENE 09 · BREAK IT, SEE IT
Break it, see it
A broken kernel writes to the wrong places — the visualization is your debugger.
__global__ void add(float* a, float* b, float* c, int n) {
int i = blockIdx.x * blockDim.x + threadIdx.x + 1;
if (i < n) c[i] = a[i] + b[i];
}Press RUN — the visualization is your debugger.
Agent-native web · research mode
Experimental WebMCP · evolving community-group draft, not a W3C Standard or on the Standards Track.
Native status: Initializing. Registered: none
DOM → inferred capabilities · WebMCP → declared capabilities. Tools read real CUDA/Inference Atlas content. Calls may highlight temporary UI state. No backend or remote telemetry.
Local harness verifies application logic; it does not demonstrate native discovery or a browser agent.
Input schema
{
"type": "object",
"properties": {
"query": {
"type": "string",
"minLength": 1,
"maxLength": 300
},
"limit": {
"type": "integer",
"minimum": 1,
"maximum": 10
}
},
"required": [
"query"
],
"additionalProperties": false
}Local log: last 100 calls while this panel is open. Inputs may contain personal text; review before sharing.
[]